---
title: <span class="badge object-type-scalar"></span> FlopsPerSecond
---
# <span class="badge object-type-scalar"></span> FlopsPerSecond

Computation: FLOP/s

## Definition

```python
# Computation: FLOP/s
FlopsPerSecond: typing.Literal["flops"] = "flops"
```
